# Init-Film  
![image](https://github.com/user-attachments/assets/9d9dd462-6b83-4ac7-a3d9-4efb88e4fb72)  
Tired of manually creating folder structures for your film/video projects?  
Want a folder structure that dynamically changes based on the needs for your project?  
Then Init-Film was made for you!  
By filmmakers, for filmmakers ;)  


## Key features  
- ♥️ Supports Windows, Linux, and macOS
- ✅ Dynamically create folder structures by selecting options from a list
- [📝](https://github.com/andreasdelabie/init-film/wiki/Usage#templates) Import file templates & project assets to reuse across multiple projects
- [📽️](https://github.com/andreasdelabie/init-film/wiki/Usage#create-proxies) Automatically create video proxies
- [🖋️](https://github.com/andreasdelabie/init-film/wiki/Usage#custom-folder-names) Use custom folder names
- [✨](https://github.com/andreasdelabie/init-film/wiki/Usage#configuration) Customize the prefix style to your preference!
- [📋](https://github.com/andreasdelabie/init-film/wiki/Usage#copy-project-title-to-clipboard) Auto copies the project title to your clipboard
- [🖱️](https://github.com/andreasdelabie/init-film/wiki/Usage#add-shortcut-to-windows-context-menu-right-click-menu) Start a new project by right-clicking in a folder and selecting "Start Init-Film Project" *(Windows only)*

->>[Watch showcase](https://www.youtube.com/watch?v=QheWe-1PqUM)<<-  


# Installation & usage
Please refer to our [Wiki](https://github.com/andreasdelabie/init-film/wiki/Installation,-updates-&-uninstalling) .


# Support  
[!["Buy Me A Coffee"](https://buymeacoffee.com/assets/img/custom_images/yellow_img.png)](https://buymeacoffee.com/andreasdelabie)
